/* Generated automatically by the program `gencodes'
   from the machine description file `md'.  */

#ifndef GCC_INSN_CODES_H
#define GCC_INSN_CODES_H

enum insn_code {
  CODE_FOR_nothing = 0,
  CODE_FOR_addsf3 = 1,
  CODE_FOR_adddf3 = 2,
  CODE_FOR_addsi3 = 3,
  CODE_FOR_adddi3 = 4,
  CODE_FOR_subsf3 = 7,
  CODE_FOR_subdf3 = 8,
  CODE_FOR_subdi3 = 9,
  CODE_FOR_subsi3 = 10,
  CODE_FOR_negdi2 = 13,
  CODE_FOR_negsi2 = 14,
  CODE_FOR_mulsf3 = 17,
  CODE_FOR_muldf3 = 18,
  CODE_FOR_mulsi3 = 19,
  CODE_FOR_muldi3 = 20,
  CODE_FOR_smuldi3_highpart = 23,
  CODE_FOR_umuldi3_highpart = 24,
  CODE_FOR_usmuldi3_highpart = 25,
  CODE_FOR_smulsi3_highpart = 26,
  CODE_FOR_umulsi3_highpart = 27,
  CODE_FOR_usmulsi3_highpart = 28,
  CODE_FOR_divsi3 = 29,
  CODE_FOR_udivsi3 = 30,
  CODE_FOR_modsi3 = 31,
  CODE_FOR_umodsi3 = 32,
  CODE_FOR_divdi3 = 33,
  CODE_FOR_udivdi3 = 34,
  CODE_FOR_moddi3 = 35,
  CODE_FOR_umoddi3 = 36,
  CODE_FOR_divsf3 = 41,
  CODE_FOR_divdf3 = 42,
  CODE_FOR_sqrtsf2 = 43,
  CODE_FOR_sqrtdf2 = 44,
  CODE_FOR_fmasf4 = 45,
  CODE_FOR_fmadf4 = 46,
  CODE_FOR_fmssf4 = 47,
  CODE_FOR_fmsdf4 = 48,
  CODE_FOR_fnmssf4 = 49,
  CODE_FOR_fnmsdf4 = 50,
  CODE_FOR_fnmasf4 = 51,
  CODE_FOR_fnmadf4 = 52,
  CODE_FOR_abssf2 = 61,
  CODE_FOR_absdf2 = 62,
  CODE_FOR_copysignsf3 = 63,
  CODE_FOR_copysigndf3 = 64,
  CODE_FOR_negsf2 = 65,
  CODE_FOR_negdf2 = 66,
  CODE_FOR_sminsf3 = 67,
  CODE_FOR_smindf3 = 68,
  CODE_FOR_smaxsf3 = 69,
  CODE_FOR_smaxdf3 = 70,
  CODE_FOR_andsi3 = 71,
  CODE_FOR_iorsi3 = 72,
  CODE_FOR_xorsi3 = 73,
  CODE_FOR_anddi3 = 74,
  CODE_FOR_iordi3 = 75,
  CODE_FOR_xordi3 = 76,
  CODE_FOR_one_cmplsi2 = 80,
  CODE_FOR_one_cmpldi2 = 81,
  CODE_FOR_truncdfsf2 = 83,
  CODE_FOR_zero_extendqihi2 = 87,
  CODE_FOR_zero_extendqisi2 = 88,
  CODE_FOR_zero_extendqidi2 = 89,
  CODE_FOR_extendsidi2 = 90,
  CODE_FOR_extendsfdf2 = 97,
  CODE_FOR_fix_truncsfsi2 = 98,
  CODE_FOR_fix_truncsfdi2 = 99,
  CODE_FOR_fix_truncdfsi2 = 100,
  CODE_FOR_fix_truncdfdi2 = 101,
  CODE_FOR_fixuns_truncsfsi2 = 102,
  CODE_FOR_fixuns_truncsfdi2 = 103,
  CODE_FOR_fixuns_truncdfsi2 = 104,
  CODE_FOR_fixuns_truncdfdi2 = 105,
  CODE_FOR_floatsisf2 = 106,
  CODE_FOR_floatdisf2 = 107,
  CODE_FOR_floatsidf2 = 108,
  CODE_FOR_floatdidf2 = 109,
  CODE_FOR_floatunssisf2 = 110,
  CODE_FOR_floatunsdisf2 = 111,
  CODE_FOR_floatunssidf2 = 112,
  CODE_FOR_floatunsdidf2 = 113,
  CODE_FOR_lrintsfsi2 = 114,
  CODE_FOR_lroundsfsi2 = 115,
  CODE_FOR_lrintsfdi2 = 116,
  CODE_FOR_lroundsfdi2 = 117,
  CODE_FOR_lrintdfsi2 = 118,
  CODE_FOR_lrounddfsi2 = 119,
  CODE_FOR_lrintdfdi2 = 120,
  CODE_FOR_lrounddfdi2 = 121,
  CODE_FOR_got_loadsi = 122,
  CODE_FOR_got_loaddi = 123,
  CODE_FOR_tls_add_tp_lesi = 124,
  CODE_FOR_tls_add_tp_ledi = 125,
  CODE_FOR_got_load_tls_gdsi = 126,
  CODE_FOR_got_load_tls_gddi = 127,
  CODE_FOR_got_load_tls_iesi = 128,
  CODE_FOR_got_load_tls_iedi = 129,
  CODE_FOR_auipcsi = 130,
  CODE_FOR_auipcdi = 131,
  CODE_FOR_fence = 148,
  CODE_FOR_fence_i = 149,
  CODE_FOR_ashlsi3 = 150,
  CODE_FOR_ashrsi3 = 151,
  CODE_FOR_lshrsi3 = 152,
  CODE_FOR_ashldi3 = 159,
  CODE_FOR_ashrdi3 = 160,
  CODE_FOR_lshrdi3 = 161,
  CODE_FOR_zero_extendsidi2_shifted = 180,
  CODE_FOR_jump = 240,
  CODE_FOR_indirect_jumpsi = 241,
  CODE_FOR_indirect_jumpdi = 242,
  CODE_FOR_tablejumpsi = 243,
  CODE_FOR_tablejumpdi = 244,
  CODE_FOR_blockage = 245,
  CODE_FOR_simple_return = 246,
  CODE_FOR_simple_return_internal = 247,
  CODE_FOR_eh_set_lr_si = 248,
  CODE_FOR_eh_set_lr_di = 249,
  CODE_FOR_eh_return_internal = 250,
  CODE_FOR_sibcall_internal = 251,
  CODE_FOR_sibcall_value_internal = 252,
  CODE_FOR_call_internal = 253,
  CODE_FOR_call_value_internal = 254,
  CODE_FOR_nop = 255,
  CODE_FOR_trap = 256,
  CODE_FOR_gpr_save = 257,
  CODE_FOR_gpr_restore = 258,
  CODE_FOR_gpr_restore_return = 259,
  CODE_FOR_riscv_frflags = 260,
  CODE_FOR_riscv_fsflags = 261,
  CODE_FOR_riscv_mret = 262,
  CODE_FOR_riscv_sret = 263,
  CODE_FOR_riscv_uret = 264,
  CODE_FOR_stack_tiesi = 265,
  CODE_FOR_stack_tiedi = 266,
  CODE_FOR_stack_protect_set_si = 267,
  CODE_FOR_stack_protect_set_di = 268,
  CODE_FOR_stack_protect_test_si = 269,
  CODE_FOR_stack_protect_test_di = 270,
  CODE_FOR_clzsi2 = 283,
  CODE_FOR_ctzsi2 = 284,
  CODE_FOR_popcountsi2 = 285,
  CODE_FOR_clzdi2 = 289,
  CODE_FOR_ctzdi2 = 290,
  CODE_FOR_popcountdi2 = 291,
  CODE_FOR_rotrsi3 = 302,
  CODE_FOR_rotrdi3 = 303,
  CODE_FOR_rotrsi3_sext = 304,
  CODE_FOR_rotlsi3 = 305,
  CODE_FOR_rotldi3 = 306,
  CODE_FOR_rotlsi3_sext = 307,
  CODE_FOR_bswapsi2 = 308,
  CODE_FOR_bswapdi2 = 309,
  CODE_FOR_sminsi3 = 310,
  CODE_FOR_uminsi3 = 311,
  CODE_FOR_smaxsi3 = 312,
  CODE_FOR_umaxsi3 = 313,
  CODE_FOR_smindi3 = 314,
  CODE_FOR_umindi3 = 315,
  CODE_FOR_smaxdi3 = 316,
  CODE_FOR_umaxdi3 = 317,
  CODE_FOR_mem_thread_fence_1 = 340,
  CODE_FOR_atomic_storesi = 341,
  CODE_FOR_atomic_storedi = 342,
  CODE_FOR_atomic_addsi = 343,
  CODE_FOR_atomic_orsi = 344,
  CODE_FOR_atomic_xorsi = 345,
  CODE_FOR_atomic_andsi = 346,
  CODE_FOR_atomic_adddi = 347,
  CODE_FOR_atomic_ordi = 348,
  CODE_FOR_atomic_xordi = 349,
  CODE_FOR_atomic_anddi = 350,
  CODE_FOR_atomic_fetch_addsi = 351,
  CODE_FOR_atomic_fetch_orsi = 352,
  CODE_FOR_atomic_fetch_xorsi = 353,
  CODE_FOR_atomic_fetch_andsi = 354,
  CODE_FOR_atomic_fetch_adddi = 355,
  CODE_FOR_atomic_fetch_ordi = 356,
  CODE_FOR_atomic_fetch_xordi = 357,
  CODE_FOR_atomic_fetch_anddi = 358,
  CODE_FOR_atomic_exchangesi = 359,
  CODE_FOR_atomic_exchangedi = 360,
  CODE_FOR_atomic_cas_value_strongsi = 361,
  CODE_FOR_atomic_cas_value_strongdi = 362,
  CODE_FOR_addvsi4 = 415,
  CODE_FOR_addvdi4 = 416,
  CODE_FOR_uaddvsi4 = 417,
  CODE_FOR_uaddvdi4 = 418,
  CODE_FOR_subvsi4 = 419,
  CODE_FOR_subvdi4 = 420,
  CODE_FOR_usubvsi4 = 421,
  CODE_FOR_usubvdi4 = 422,
  CODE_FOR_mulvsi4 = 423,
  CODE_FOR_mulvdi4 = 424,
  CODE_FOR_umulvsi4 = 425,
  CODE_FOR_umulvdi4 = 426,
  CODE_FOR_mulditi3 = 427,
  CODE_FOR_umulditi3 = 428,
  CODE_FOR_usmulditi3 = 429,
  CODE_FOR_mulsidi3 = 430,
  CODE_FOR_umulsidi3 = 431,
  CODE_FOR_usmulsidi3 = 432,
  CODE_FOR_zero_extendsidi2 = 433,
  CODE_FOR_zero_extendhisi2 = 434,
  CODE_FOR_zero_extendhidi2 = 435,
  CODE_FOR_extendqihi2 = 436,
  CODE_FOR_extendqisi2 = 437,
  CODE_FOR_extendqidi2 = 438,
  CODE_FOR_extendhihi2 = 439,
  CODE_FOR_extendhisi2 = 440,
  CODE_FOR_extendhidi2 = 441,
  CODE_FOR_movdi = 442,
  CODE_FOR_movsi = 443,
  CODE_FOR_movhi = 444,
  CODE_FOR_movqi = 445,
  CODE_FOR_movsf = 446,
  CODE_FOR_movdf = 447,
  CODE_FOR_cpymemsi = 448,
  CODE_FOR_clear_cache = 449,
  CODE_FOR_movsicc = 450,
  CODE_FOR_movdicc = 451,
  CODE_FOR_condjump = 452,
  CODE_FOR_cbranchqi4 = 453,
  CODE_FOR_cbranchsi4 = 454,
  CODE_FOR_cbranchdi4 = 455,
  CODE_FOR_cbranchsf4 = 456,
  CODE_FOR_cbranchdf4 = 457,
  CODE_FOR_cstoresi4 = 458,
  CODE_FOR_cstoredi4 = 459,
  CODE_FOR_cstoresf4 = 460,
  CODE_FOR_cstoredf4 = 461,
  CODE_FOR_flt_quietsfsi4 = 462,
  CODE_FOR_fle_quietsfsi4 = 463,
  CODE_FOR_flt_quietsfdi4 = 464,
  CODE_FOR_fle_quietsfdi4 = 465,
  CODE_FOR_flt_quietdfsi4 = 466,
  CODE_FOR_fle_quietdfsi4 = 467,
  CODE_FOR_flt_quietdfdi4 = 468,
  CODE_FOR_fle_quietdfdi4 = 469,
  CODE_FOR_indirect_jump = 470,
  CODE_FOR_tablejump = 471,
  CODE_FOR_prologue = 472,
  CODE_FOR_epilogue = 473,
  CODE_FOR_sibcall_epilogue = 474,
  CODE_FOR_return = 475,
  CODE_FOR_eh_return = 476,
  CODE_FOR_sibcall = 477,
  CODE_FOR_sibcall_value = 478,
  CODE_FOR_call = 479,
  CODE_FOR_call_value = 480,
  CODE_FOR_untyped_call = 481,
  CODE_FOR_restore_stack_nonlocal = 482,
  CODE_FOR_get_thread_pointersi = 483,
  CODE_FOR_get_thread_pointerdi = 484,
  CODE_FOR_stack_protect_set = 485,
  CODE_FOR_stack_protect_test = 486,
  CODE_FOR_mem_thread_fence = 487,
  CODE_FOR_atomic_compare_and_swapsi = 488,
  CODE_FOR_atomic_compare_and_swapdi = 489,
  CODE_FOR_atomic_test_and_set = 490
};

const unsigned int NUM_INSN_CODES = 491;
#endif /* GCC_INSN_CODES_H */
